@@ -14,7 +14,7 @@ from httpx import (
 from meilisearch_python_async.errors import MeiliSearchApiError, MeiliSearchCommunicationError
 
 
-class _HttpRequests:
+class HttpRequests:
     def __init__(self, http_client: AsyncClient) -> None:
         self.http_client = http_client
 
@@ -23,38 +23,27 @@ class _HttpRequests:
         http_method: Callable,
         path: str,
         body: Any | None = None,
-        content_type: str | None = None,
+        content_type: str = "applicaiton/json",
     ) -> Response:
         try:
             if not body:
                 response = await http_method(path)
+            elif content_type != "application/json":
+                response = await http_method(
+                    path, content=body, headers={"Content-Type": content_type}
+                )
             else:
-                if content_type is None:
-                    content_type = "application/json"
-
-                if content_type != "application/json":
-                    response = await http_method(
-                        path, content=body, headers={"Content-Type": content_type}
-                    )
-                else:
-                    response = await http_method(
-                        path, json=body, headers={"Content-Type": content_type}
-                    )
+                response = await http_method(
+                    path, json=body, headers={"Content-Type": content_type}
+                )
 
             response.raise_for_status()
             return response
 
-        except RemoteProtocolError as err:
-            raise MeiliSearchCommunicationError(str(err)) from err
-        except ConnectError as err:
-            raise MeiliSearchCommunicationError(str(err)) from err
-        except ConnectTimeout as err:
+        except (ConnectError, ConnectTimeout, RemoteProtocolError) as err:
             raise MeiliSearchCommunicationError(str(err)) from err
         except HTTPError as err:
-            if response:
-                raise MeiliSearchApiError(str(err), response) from err
-
-            raise
+            raise MeiliSearchApiError(str(err), response) from err
 
     async def get(self, path: str) -> Response:
         return await self._send_request(self.http_client.get, path)
