@@ -5,7 +5,7 @@ from typing import Type
 
 from httpx import AsyncClient
 
-from meilisearch_python_async._http_requests import _HttpRequests
+from meilisearch_python_async._http_requests import HttpRequests
 from meilisearch_python_async.errors import MeiliSearchApiError
 from meilisearch_python_async.index import Index
 from meilisearch_python_async.models.client import ClientStats, Keys
@@ -31,7 +31,7 @@ class Client:
         self._http_client = AsyncClient(
             base_url=url, timeout=timeout, headers=self._set_headers(api_key)
         )
-        self._http_requests = _HttpRequests(self._http_client)
+        self._http_requests = HttpRequests(self._http_client)
 
     async def __aenter__(self) -> Client:
         return self
@@ -123,12 +123,13 @@ class Client:
         try:
             url = f"indexes/{uid}"
             await self._http_requests.delete(url)
-            return True
         except MeiliSearchApiError as error:
             if error.code != "index_not_found":
-                raise error
+                raise
             return False
 
+        return True
+
     async def get_indexes(self) -> list[Index] | None:
         """Get all indexes.
 
@@ -274,7 +275,7 @@ class Client:
 
         * **MeilisearchCommunicationError:** If there was an error communicating with the server.
         * **MeilisearchApiError:** If the MeiliSearch API returned an error.MeiliSearchTimeoutError: If the connection times out.
-            MeiliSearchTimeoutError: If the connection times out.
+        * **MeiliSearchTimeoutError:** If the connection times out.
 
         Usage:
 
@@ -288,7 +289,7 @@ class Client:
             index_instance = await self.get_index(uid)
         except MeiliSearchApiError as err:
             if "index_not_found" not in err.code:
-                raise err
+                raise
             index_instance = await self.create_index(uid, primary_key)
         return index_instance
 
