@@ -1,6 +1,12 @@
 from httpx import Response
 
 
+class InvalidDocumentError(Exception):
+    """Error for documents that are not in a valid format for MeiliSearch."""
+
+    pass
+
+
 class MeiliSearchError(Exception):
     """Generic class for MeiliSearch error handling."""
 
@@ -17,19 +23,21 @@ class MeiliSearchApiError(MeiliSearchError):
 
     def __init__(self, error: str, response: Response) -> None:
         self.status_code = response.status_code
-        self.error_code = ""
+        self.code = ""
         self.message = ""
-        self.error_link = ""
+        self.link = ""
+        self.error_type = ""
         if response.content:
             self.message = f" Error message: {response.json().get('message') or ''}."
-            self.error_code = f"{response.json().get('errorCode') or ''}"
-            self.error_link = f" Error documentation: {response.json().get('errorLink') or ''}"
+            self.code = f"{response.json().get('code') or ''}"
+            self.error_type = f"{response.json().get('type') or ''}"
+            self.link = f" Error documentation: {response.json().get('link') or ''}"
         else:
             self.message = error
         super().__init__(self.message)
 
     def __str__(self) -> str:
-        return f"MeiliSearchApiError.{self.error_code}{self.message}{self.error_link}"
+        return f"MeiliSearchApiError.{self.code}{self.message}{self.error_type}{self.link}"
 
 
 class MeiliSearchCommunicationError(MeiliSearchError):
